# Dev Container

Space Robotics Bench includes a [Dev Container](https://containers.dev) configuration via [`devcontainer.json`](https://github.com/AndrejOrsula/space_robotics_bench/blob/main/.devcontainer/devcontainer.json) that you can customize for your development needs.

## Open in VS Code

For convenience, [Visual Studio Code (VS Code)](https://code.visualstudio.com) users can open the repository as a Dev Container by running the following [script](https://github.com/AndrejOrsula/space_robotics_bench/blob/main/.devcontainer/open.bash):

```bash
./space_robotics_bench/.devcontainer/open.bash
```
